<?php

namespace App\Http\Controllers;

use App\Models\Service;
use App\Models\Bank;
use App\Models\User;
use App\Models\Order;
use App\Models\Config;
use Illuminate\Http\Request;

class AdminController extends Controller
{
    public function __construct()
    {
        $this->middleware('admin');
    }

    public function index()
    {
        return view('admin.index');
    }

    public function services()
    {
        $services = Service::all();
        return view('admin.services', compact('services'));
    }

    public function addService(Request $request)
    {
        Service::create($request->only('name', 'price', 'desc', 'details'));
        return redirect()->back()->with('success', 'Thêm dịch vụ thành công');
    }

    public function updateService(Request $request, $id)
    {
        Service::find($id)->update($request->only('name', 'price', 'desc', 'details'));
        return redirect()->back()->with('success', 'Cập nhật dịch vụ thành công');
    }

    public function deleteService($id)
    {
        Service::find($id)->delete();
        return redirect()->back()->with('success', 'Xóa dịch vụ thành công');
    }

    public function banks()
    {
        $banks = Bank::all();
        return view('admin.banks', compact('banks'));
    }

    public function addBank(Request $request)
    {
        Bank::create($request->only('bank_name', 'account_number', 'account_holder'));
        return redirect()->back()->with('success', 'Thêm ngân hàng thành công');
    }

    public function config()
    {
        $configs = Config::all()->pluck('value', 'key');
        return view('admin.config', compact('configs'));
    }

    public function saveConfig(Request $request)
    {
        Config::updateOrCreate(['key' => 'site_name'], ['value' => $request->site_name]);
        Config::updateOrCreate(['key' => 'theme_color'], ['value' => $request->theme_color]);
        Config::updateOrCreate(['key' => 'telegram_token'], ['value' => $request->telegram_token]);
        Config::updateOrCreate(['key' => 'telegram_chat_id'], ['value' => $request->telegram_chat_id]);
        return redirect()->back()->with('success', 'Cập nhật cấu hình thành công');
    }

    public function users()
    {
        $users = User::all();
        return view('admin.users', compact('users'));
    }

    public function updateUser(Request $request, $id)
    {
        User::find($id)->update($request->only('email', 'balance'));
        return redirect()->back()->with('success', 'Cập nhật user thành công');
    }

    public function adjustBalance(Request $request, $id)
    {
        $user = User::find($id);
        if ($request->action == 'add') {
            $user->balance += $request->amount;
        } else {
            $user->balance -= $request->amount;
        }
        $user->save();
        return redirect()->back()->with('success', 'Cập nhật số dư thành công');
    }

    public function orders()
    {
        $orders = Order::with('service')->get();
        return view('admin.orders', compact('orders'));
    }

    public function updateOrder(Request $request, $id)
    {
        Order::find($id)->update(['status' => $request->status]);
        return redirect()->back()->with('success', 'Cập nhật đơn hàng thành công');
    }
}