<?php

namespace App\Http\Controllers;

use App\Models\Service;
use App\Models\Order;
use App\Models\Config;
use Illuminate\Http\Request;

class ShopController extends Controller
{
    public function index()
    {
        $services = Service::where('sold', false)->get();
        return view('shop', compact('services'));
    }

    public function buy(Request $request, $id)
    {
        $service = Service::find($id);
        if (!$service || $service->sold) {
            return redirect()->back()->with('error', 'Tài khoản không tồn tại hoặc đã bán');
        }

        $paymentResult = $this->processPayment($service->price, $request->payment_method);
        if ($paymentResult['success']) {
            $service->sold = true;
            $service->save();

            Order::create([
                'service_id' => $id,
                'email' => $request->email,
                'payment_method' => $request->payment_method,
                'status' => 'completed',
            ]);

            $this->sendTelegramNotification($service, $request->email);
            return redirect()->back()->with('success', "Mua thành công! Thông tin: {$service->details}");
        }
        return redirect()->back()->with('error', 'Thanh toán thất bại');
    }

    private function processPayment($amount, $method)
    {
        return ['success' => true]; // Giả lập, thay bằng API MoMo nếu cần
    }

    private function sendTelegramNotification($service, $email)
    {
        $token = Config::where('key', 'telegram_token')->value('value');
        $chatId = Config::where('key', 'telegram_chat_id')->value('value');
        if ($token && $chatId) {
            $message = "Đơn hàng mới: {$service->name} - Giá: {$service->price} VNĐ - Email: {$email}";
            file_get_contents("https://api.telegram.org/bot{$token}/sendMessage?chat_id={$chatId}&text=" . urlencode($message));
        }
    }
}